==> jc-1.4.0.tar.gz: soot/tagkit/FirstTagAggregator.h <==
// public abstract class soot.tagkit.FirstTagAggregator

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class a76a7734eb62f430 soot_BodyTransformer
// @dep_class de5fa3182955e270 soot_Transformer
// @dep_class 2b6b5cefdfd44ac3 soot_tagkit_FirstTagAggregator
// @dep_class 62bfb9a4e3139951 soot_tagkit_TagAggregator

// header file dependencies
// @dep_header soot_tagkit_TagAggregator

#include "soot/tagkit/TagAggregator.h"

#ifndef _JC_soot_tagkit_FirstTagAggregator_H_
#define _JC_soot_tagkit_FirstTagAggregator_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_soot_Unit$object;
struct _jc_soot_tagkit_Tag$object;

// Typedefs
typedef struct _jc_soot_tagkit_FirstTagAggregator$sub_refs	_jc_soot_tagkit_FirstTagAggregator$sub_refs;
typedef struct _jc_soot_tagkit_FirstTagAggregator$sub_nonrefs	_jc_soot_tagkit_FirstTagAggregator$sub_nonrefs;
typedef struct _jc_soot_tagkit_FirstTagAggregator$refs	_jc_soot_tagkit_FirstTagAggregator$refs;
typedef struct _jc_soot_tagkit_FirstTagAggregator$nonrefs	_jc_soot_tagkit_FirstTagAggregator$nonrefs;
typedef struct _jc_soot_tagkit_FirstTagAggregator$object	_jc_soot_tagkit_FirstTagAggregator$object;

typedef const struct _jc_soot_tagkit_FirstTagAggregator$vmethods	_jc_soot_tagkit_FirstTagAggregator$vmethods;
typedef const struct _jc_soot_tagkit_FirstTagAggregator$vtable	_jc_soot_tagkit_FirstTagAggregator$vtable;
typedef const struct _jc_soot_tagkit_FirstTagAggregator$vtype	_jc_soot_tagkit_FirstTagAggregator$vtype;

// Constructors
extern void _jc_soot_tagkit_FirstTagAggregator$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_tagkit_FirstTagAggregator$object *);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_soot_tagkit_FirstTagAggregator$method$aggregatedName$7a98c3a9832c3f1d(_jc_env *, struct _jc_soot_tagkit_FirstTagAggregator$object *);
extern void _jc_soot_tagkit_FirstTagAggregator$method$considerTag$d40cb36f11e25c13(_jc_env *, struct _jc_soot_tagkit_FirstTagAggregator$object *, struct _jc_object *, struct _jc_object *);
extern jboolean _jc_soot_tagkit_FirstTagAggregator$method$wantTag$6a073a64332a7aa0(_jc_env *, struct _jc_soot_tagkit_FirstTagAggregator$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_soot_tagkit_FirstTagAggregator$method_info$aggregatedName$7a98c3a9832c3f1d;
extern _jc_method _jc_soot_tagkit_FirstTagAggregator$method_info$considerTag$d40cb36f11e25c13;
extern _jc_method _jc_soot_tagkit_FirstTagAggregator$method_info$wantTag$6a073a64332a7aa0;

// Virtual methods structure
struct _jc_soot_tagkit_FirstTagAggregator$vmethods {
	struct _jc_java_lang_String$object	*(*aggregatedName$7a98c3a9832c3f1d)(_jc_env *, struct _jc_soot_tagkit_FirstTagAggregator$object *);
	void	(*considerTag$d40cb36f11e25c13)(_jc_env *, struct _jc_soot_tagkit_FirstTagAggregator$object *, struct _jc_object *, struct _jc_object *);
	jboolean	(*wantTag$6a073a64332a7aa0)(_jc_env *, struct _jc_soot_tagkit_FirstTagAggregator$object *, struct _jc_object *);
};

// Vtable
struct _jc_soot_tagkit_FirstTagAggregator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_Transformer$vmethods	soot_Transformer;
	_jc_soot_BodyTransformer$vmethods	soot_BodyTransformer;
	_jc_soot_tagkit_TagAggregator$vmethods	soot_tagkit_TagAggregator;
	_jc_soot_tagkit_FirstTagAggregator$vmethods	soot_tagkit_FirstTagAggregator;
};

// Vtype
struct _jc_soot_tagkit_FirstTagAggregator$vtype {
	_jc_type			type;
	_jc_soot_tagkit_FirstTagAggregator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_tagkit_FirstTagAggregator$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_tagkit_FirstTagAggregator$refs {
    _jc_soot_tagkit_FirstTagAggregator$sub_refs	soot_tagkit_FirstTagAggregator;
    _jc_soot_tagkit_TagAggregator$sub_refs	soot_tagkit_TagAggregator;
    _jc_soot_BodyTransformer$sub_refs	soot_BodyTransformer;
    _jc_soot_Transformer$sub_refs	soot_Transformer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_tagkit_FirstTagAggregator$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_tagkit_FirstTagAggregator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_Transformer$sub_nonrefs	soot_Transformer;
    _jc_soot_BodyTransformer$sub_nonrefs	soot_BodyTransformer;
    _jc_soot_tagkit_TagAggregator$sub_nonrefs	soot_tagkit_TagAggregator;
    _jc_soot_tagkit_FirstTagAggregator$sub_nonrefs	soot_tagkit_FirstTagAggregator;
};

// Object instance structure
struct _jc_soot_tagkit_FirstTagAggregator$object {
	_jc_soot_tagkit_FirstTagAggregator$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_tagkit_FirstTagAggregator$vtype	*vtype;
	_jc_soot_tagkit_FirstTagAggregator$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_tagkit_FirstTagAggregator$vtype _jc_soot_tagkit_FirstTagAggregator$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_tagkit_FirstTagAggregator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_tagkit_FirstTagAggregator$class_object;

#endif	/* _JC_soot_tagkit_FirstTagAggregator_H_ */

==> jc-1.4.6.tar.gz: soot/tagkit/FirstTagAggregator.h <==
// public abstract class soot.tagkit.FirstTagAggregator

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class a76a7734eb62f430 soot_BodyTransformer
// @dep_class de5fa3182955e270 soot_Transformer
// @dep_class 2b6b5cefdfd44ac3 soot_tagkit_FirstTagAggregator
// @dep_class 62bfb9a4e3139951 soot_tagkit_TagAggregator

// header file dependencies
// @dep_header soot_tagkit_TagAggregator

#include "soot/tagkit/TagAggregator.h"

#ifndef _JC_soot_tagkit_FirstTagAggregator_H_
#define _JC_soot_tagkit_FirstTagAggregator_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_soot_Unit$object;
struct _jc_soot_tagkit_Tag$object;

// Typedefs
typedef struct _jc_soot_tagkit_FirstTagAggregator$sub_refs	_jc_soot_tagkit_FirstTagAggregator$sub_refs;
typedef struct _jc_soot_tagkit_FirstTagAggregator$sub_nonrefs	_jc_soot_tagkit_FirstTagAggregator$sub_nonrefs;
typedef struct _jc_soot_tagkit_FirstTagAggregator$refs	_jc_soot_tagkit_FirstTagAggregator$refs;
typedef struct _jc_soot_tagkit_FirstTagAggregator$nonrefs	_jc_soot_tagkit_FirstTagAggregator$nonrefs;
typedef struct _jc_soot_tagkit_FirstTagAggregator$object	_jc_soot_tagkit_FirstTagAggregator$object;

typedef const struct _jc_soot_tagkit_FirstTagAggregator$vmethods	_jc_soot_tagkit_FirstTagAggregator$vmethods;
typedef const struct _jc_soot_tagkit_FirstTagAggregator$vtable	_jc_soot_tagkit_FirstTagAggregator$vtable;
typedef const struct _jc_soot_tagkit_FirstTagAggregator$vtype	_jc_soot_tagkit_FirstTagAggregator$vtype;

// Constructors
extern void _jc_soot_tagkit_FirstTagAggregator$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_tagkit_FirstTagAggregator$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_soot_tagkit_FirstTagAggregator$method$aggregatedName$7a98c3a9832c3f1d(_jc_env *, struct _jc_soot_tagkit_FirstTagAggregator$object *) _JC_JCNI_ATTR;
extern void _jc_soot_tagkit_FirstTagAggregator$method$considerTag$d40cb36f11e25c13(_jc_env *, struct _jc_soot_tagkit_FirstTagAggregator$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
extern jboolean _jc_soot_tagkit_FirstTagAggregator$method$wantTag$6a073a64332a7aa0(_jc_env *, struct _jc_soot_tagkit_FirstTagAggregator$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_tagkit_FirstTagAggregator$method_info$aggregatedName$7a98c3a9832c3f1d;
extern _jc_method _jc_soot_tagkit_FirstTagAggregator$method_info$considerTag$d40cb36f11e25c13;
extern _jc_method _jc_soot_tagkit_FirstTagAggregator$method_info$wantTag$6a073a64332a7aa0;

// Virtual methods structure
struct _jc_soot_tagkit_FirstTagAggregator$vmethods {
	struct _jc_java_lang_String$object	*(*aggregatedName$7a98c3a9832c3f1d)(_jc_env *, struct _jc_soot_tagkit_FirstTagAggregator$object *) _JC_JCNI_ATTR;
	void	(*considerTag$d40cb36f11e25c13)(_jc_env *, struct _jc_soot_tagkit_FirstTagAggregator$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
	jboolean	(*wantTag$6a073a64332a7aa0)(_jc_env *, struct _jc_soot_tagkit_FirstTagAggregator$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_tagkit_FirstTagAggregator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_Transformer$vmethods	soot_Transformer;
	_jc_soot_BodyTransformer$vmethods	soot_BodyTransformer;
	_jc_soot_tagkit_TagAggregator$vmethods	soot_tagkit_TagAggregator;
	_jc_soot_tagkit_FirstTagAggregator$vmethods	soot_tagkit_FirstTagAggregator;
};

// Vtype
struct _jc_soot_tagkit_FirstTagAggregator$vtype {
	_jc_type			type;
	_jc_soot_tagkit_FirstTagAggregator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_tagkit_FirstTagAggregator$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_tagkit_FirstTagAggregator$refs {
    _jc_soot_tagkit_FirstTagAggregator$sub_refs	soot_tagkit_FirstTagAggregator;
    _jc_soot_tagkit_TagAggregator$sub_refs	soot_tagkit_TagAggregator;
    _jc_soot_BodyTransformer$sub_refs	soot_BodyTransformer;
    _jc_soot_Transformer$sub_refs	soot_Transformer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_tagkit_FirstTagAggregator$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_tagkit_FirstTagAggregator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_Transformer$sub_nonrefs	soot_Transformer;
    _jc_soot_BodyTransformer$sub_nonrefs	soot_BodyTransformer;
    _jc_soot_tagkit_TagAggregator$sub_nonrefs	soot_tagkit_TagAggregator;
    _jc_soot_tagkit_FirstTagAggregator$sub_nonrefs	soot_tagkit_FirstTagAggregator;
};

// Object instance structure
struct _jc_soot_tagkit_FirstTagAggregator$object {
	_jc_soot_tagkit_FirstTagAggregator$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_tagkit_FirstTagAggregator$vtype	*vtype;
	_jc_soot_tagkit_FirstTagAggregator$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_tagkit_FirstTagAggregator$vtype _jc_soot_tagkit_FirstTagAggregator$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_tagkit_FirstTagAggregator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_tagkit_FirstTagAggregator$class_object;

#endif	/* _JC_soot_tagkit_FirstTagAggregator_H_ */
